==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/ActiveDirectoryPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.ActiveDirectoryPropertiesArgs.builder
import com.pulumi.azurenative.storage.kotlin.enums.AccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Settings properties for Active Directory (AD).
 * @property accountType Specifies the Active Directory account type for Azure Storage.
 * @property azureStorageSid Specifies the security identifier (SID) for Azure Storage.
 * @property domainGuid Specifies the domain GUID.
 * @property domainName Specifies the primary domain that the AD DNS server is authoritative for.
 * @property domainSid Specifies the security identifier (SID).
 * @property forestName Specifies the Active Directory forest to get.
 * @property netBiosDomainName Specifies the NetBIOS domain name.
 * @property samAccountName Specifies the Active Directory SAMAccountName for Azure Storage.
 */
public data class ActiveDirectoryPropertiesArgs(
    public val accountType: Output<Either<String, AccountType>>? = null,
    public val azureStorageSid: Output<String>? = null,
    public val domainGuid: Output<String>,
    public val domainName: Output<String>,
    public val domainSid: Output<String>? = null,
    public val forestName: Output<String>? = null,
    public val netBiosDomainName: Output<String>? = null,
    public val samAccountName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.ActiveDirectoryPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.ActiveDirectoryPropertiesArgs =
        com.pulumi.azurenative.storage.inputs.ActiveDirectoryPropertiesArgs.builder()
            .accountType(
                accountType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .azureStorageSid(azureStorageSid?.applyValue({ args0 -> args0 }))
            .domainGuid(domainGuid.applyValue({ args0 -> args0 }))
            .domainName(domainName.applyValue({ args0 -> args0 }))
            .domainSid(domainSid?.applyValue({ args0 -> args0 }))
            .forestName(forestName?.applyValue({ args0 -> args0 }))
            .netBiosDomainName(netBiosDomainName?.applyValue({ args0 -> args0 }))
            .samAccountName(samAccountName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ActiveDirectoryPropertiesArgs].
 */
@PulumiTagMarker
public class ActiveDirectoryPropertiesArgsBuilder internal constructor() {
    private var accountType: Output<Either<String, AccountType>>? = null

    private var azureStorageSid: Output<String>? = null

    private var domainGuid: Output<String>? = null

    private var domainName: Output<String>? = null

    private var domainSid: Output<String>? = null

    private var forestName: Output<String>? = null

    private var netBiosDomainName: Output<String>? = null

    private var samAccountName: Output<String>? = null

    /**
     * @param value Specifies the Active Directory account type for Azure Storage.
     */
    @JvmName("epbctpsgumdwcjwx")
    public suspend fun accountType(`value`: Output<Either<String, AccountType>>) {
        this.accountType = value
    }

    /**
     * @param value Specifies the security identifier (SID) for Azure Storage.
     */
    @JvmName("icibvplkgpksfxpm")
    public suspend fun azureStorageSid(`value`: Output<String>) {
        this.azureStorageSid = value
    }

    /**
     * @param value Specifies the domain GUID.
     */
    @JvmName("dmmryxpxlfyhbbqu")
    public suspend fun domainGuid(`value`: Output<String>) {
        this.domainGuid = value
    }

    /**
     * @param value Specifies the primary domain that the AD DNS server is authoritative for.
     */
    @JvmName("amndvvgkmogqtlld")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value Specifies the security identifier (SID).
     */
    @JvmName("qbpqaocfnwtrbxsq")
    public suspend fun domainSid(`value`: Output<String>) {
        this.domainSid = value
    }

    /**
     * @param value Specifies the Active Directory forest to get.
     */
    @JvmName("xhceyjbhrpeamuoc")
    public suspend fun forestName(`value`: Output<String>) {
        this.forestName = value
    }

    /**
     * @param value Specifies the NetBIOS domain name.
     */
    @JvmName("wyjkanxvjxhermnq")
    public suspend fun netBiosDomainName(`value`: Output<String>) {
        this.netBiosDomainName = value
    }

    /**
     * @param value Specifies the Active Directory SAMAccountName for Azure Storage.
     */
    @JvmName("yaghmsbrhkprmtfg")
    public suspend fun samAccountName(`value`: Output<String>) {
        this.samAccountName = value
    }

    /**
     * @param value Specifies the Active Directory account type for Azure Storage.
     */
    @JvmName("aqhhqttoiarhejcd")
    public suspend fun accountType(`value`: Either<String, AccountType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountType = mapped
    }

    /**
     * @param value Specifies the Active Directory account type for Azure Storage.
     */
    @JvmName("khkmngaldtjjeqqm")
    public fun accountType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountType = mapped
    }

    /**
     * @param value Specifies the Active Directory account type for Azure Storage.
     */
    @JvmName("vnqftshpttmstipk")
    public fun accountType(`value`: AccountType) {
        val toBeMapped = Either.ofRight<String, AccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountType = mapped
    }

    /**
     * @param value Specifies the security identifier (SID) for Azure Storage.
     */
    @JvmName("nonqsxyvefjibbdy")
    public suspend fun azureStorageSid(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureStorageSid = mapped
    }

    /**
     * @param value Specifies the domain GUID.
     */
    @JvmName("inqpvmornmpqljfj")
    public suspend fun domainGuid(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domainGuid = mapped
    }

    /**
     * @param value Specifies the primary domain that the AD DNS server is authoritative for.
     */
    @JvmName("bgjaawcotbmlccpu")
    public suspend fun domainName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value Specifies the security identifier (SID).
     */
    @JvmName("qrjlxwbqvdocgjxu")
    public suspend fun domainSid(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainSid = mapped
    }

    /**
     * @param value Specifies the Active Directory forest to get.
     */
    @JvmName("tnddwuyfjbvfyuyu")
    public suspend fun forestName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forestName = mapped
    }

    /**
     * @param value Specifies the NetBIOS domain name.
     */
    @JvmName("qreyymrbdjlokpis")
    public suspend fun netBiosDomainName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.netBiosDomainName = mapped
    }

    /**
     * @param value Specifies the Active Directory SAMAccountName for Azure Storage.
     */
    @JvmName("ikmnstjkbustvnys")
    public suspend fun samAccountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.samAccountName = mapped
    }

    internal fun build(): ActiveDirectoryPropertiesArgs = ActiveDirectoryPropertiesArgs(
        accountType = accountType,
        azureStorageSid = azureStorageSid,
        domainGuid = domainGuid ?: throw PulumiNullFieldException("domainGuid"),
        domainName = domainName ?: throw PulumiNullFieldException("domainName"),
        domainSid = domainSid,
        forestName = forestName,
        netBiosDomainName = netBiosDomainName,
        samAccountName = samAccountName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/ActiveDirectoryPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.ActiveDirectoryPropertiesArgs.builder
import com.pulumi.azurenative.storage.kotlin.enums.AccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Settings properties for Active Directory (AD).
 * @property accountType Specifies the Active Directory account type for Azure Storage.
 * @property azureStorageSid Specifies the security identifier (SID) for Azure Storage.
 * @property domainGuid Specifies the domain GUID.
 * @property domainName Specifies the primary domain that the AD DNS server is authoritative for.
 * @property domainSid Specifies the security identifier (SID).
 * @property forestName Specifies the Active Directory forest to get.
 * @property netBiosDomainName Specifies the NetBIOS domain name.
 * @property samAccountName Specifies the Active Directory SAMAccountName for Azure Storage.
 */
public data class ActiveDirectoryPropertiesArgs(
    public val accountType: Output<Either<String, AccountType>>? = null,
    public val azureStorageSid: Output<String>? = null,
    public val domainGuid: Output<String>,
    public val domainName: Output<String>,
    public val domainSid: Output<String>? = null,
    public val forestName: Output<String>? = null,
    public val netBiosDomainName: Output<String>? = null,
    public val samAccountName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.ActiveDirectoryPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.ActiveDirectoryPropertiesArgs =
        com.pulumi.azurenative.storage.inputs.ActiveDirectoryPropertiesArgs.builder()
            .accountType(
                accountType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .azureStorageSid(azureStorageSid?.applyValue({ args0 -> args0 }))
            .domainGuid(domainGuid.applyValue({ args0 -> args0 }))
            .domainName(domainName.applyValue({ args0 -> args0 }))
            .domainSid(domainSid?.applyValue({ args0 -> args0 }))
            .forestName(forestName?.applyValue({ args0 -> args0 }))
            .netBiosDomainName(netBiosDomainName?.applyValue({ args0 -> args0 }))
            .samAccountName(samAccountName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ActiveDirectoryPropertiesArgs].
 */
@PulumiTagMarker
public class ActiveDirectoryPropertiesArgsBuilder internal constructor() {
    private var accountType: Output<Either<String, AccountType>>? = null

    private var azureStorageSid: Output<String>? = null

    private var domainGuid: Output<String>? = null

    private var domainName: Output<String>? = null

    private var domainSid: Output<String>? = null

    private var forestName: Output<String>? = null

    private var netBiosDomainName: Output<String>? = null

    private var samAccountName: Output<String>? = null

    /**
     * @param value Specifies the Active Directory account type for Azure Storage.
     */
    @JvmName("vwqmbgvdsrsdodaj")
    public suspend fun accountType(`value`: Output<Either<String, AccountType>>) {
        this.accountType = value
    }

    /**
     * @param value Specifies the security identifier (SID) for Azure Storage.
     */
    @JvmName("rljxkdxividgxsoc")
    public suspend fun azureStorageSid(`value`: Output<String>) {
        this.azureStorageSid = value
    }

    /**
     * @param value Specifies the domain GUID.
     */
    @JvmName("pjecxfbisbshifhq")
    public suspend fun domainGuid(`value`: Output<String>) {
        this.domainGuid = value
    }

    /**
     * @param value Specifies the primary domain that the AD DNS server is authoritative for.
     */
    @JvmName("xtukuvmqxmtacbxv")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value Specifies the security identifier (SID).
     */
    @JvmName("kywmtvsreeqongly")
    public suspend fun domainSid(`value`: Output<String>) {
        this.domainSid = value
    }

    /**
     * @param value Specifies the Active Directory forest to get.
     */
    @JvmName("lekgignigpjupsce")
    public suspend fun forestName(`value`: Output<String>) {
        this.forestName = value
    }

    /**
     * @param value Specifies the NetBIOS domain name.
     */
    @JvmName("ocdswpsvisarpjys")
    public suspend fun netBiosDomainName(`value`: Output<String>) {
        this.netBiosDomainName = value
    }

    /**
     * @param value Specifies the Active Directory SAMAccountName for Azure Storage.
     */
    @JvmName("wodxbekvjwldtqjl")
    public suspend fun samAccountName(`value`: Output<String>) {
        this.samAccountName = value
    }

    /**
     * @param value Specifies the Active Directory account type for Azure Storage.
     */
    @JvmName("cfxxsgtyjgtfpaph")
    public suspend fun accountType(`value`: Either<String, AccountType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountType = mapped
    }

    /**
     * @param value Specifies the Active Directory account type for Azure Storage.
     */
    @JvmName("ssplusdirsvbupql")
    public fun accountType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountType = mapped
    }

    /**
     * @param value Specifies the Active Directory account type for Azure Storage.
     */
    @JvmName("jugnpkkjxinmrafc")
    public fun accountType(`value`: AccountType) {
        val toBeMapped = Either.ofRight<String, AccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountType = mapped
    }

    /**
     * @param value Specifies the security identifier (SID) for Azure Storage.
     */
    @JvmName("tskmkwteuamofbwj")
    public suspend fun azureStorageSid(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureStorageSid = mapped
    }

    /**
     * @param value Specifies the domain GUID.
     */
    @JvmName("vxwcxenteimxvjvg")
    public suspend fun domainGuid(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domainGuid = mapped
    }

    /**
     * @param value Specifies the primary domain that the AD DNS server is authoritative for.
     */
    @JvmName("fbnaukflrykjqcvh")
    public suspend fun domainName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value Specifies the security identifier (SID).
     */
    @JvmName("ssmowgoryvnidusg")
    public suspend fun domainSid(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainSid = mapped
    }

    /**
     * @param value Specifies the Active Directory forest to get.
     */
    @JvmName("rtwrviqplrwexyar")
    public suspend fun forestName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forestName = mapped
    }

    /**
     * @param value Specifies the NetBIOS domain name.
     */
    @JvmName("qdglpibwcjnrgwfu")
    public suspend fun netBiosDomainName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.netBiosDomainName = mapped
    }

    /**
     * @param value Specifies the Active Directory SAMAccountName for Azure Storage.
     */
    @JvmName("kamfjjxsqtobuvhd")
    public suspend fun samAccountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.samAccountName = mapped
    }

    internal fun build(): ActiveDirectoryPropertiesArgs = ActiveDirectoryPropertiesArgs(
        accountType = accountType,
        azureStorageSid = azureStorageSid,
        domainGuid = domainGuid ?: throw PulumiNullFieldException("domainGuid"),
        domainName = domainName ?: throw PulumiNullFieldException("domainName"),
        domainSid = domainSid,
        forestName = forestName,
        netBiosDomainName = netBiosDomainName,
        samAccountName = samAccountName,
    )
}
